@@ -1,14 +1,14 @@
 package Complete::Dist;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-09-09'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 #use Log::Any '$log';
 
-use Complete;
+use Complete::Setting;
 
 our %SPEC;
 require Exporter;
@@ -43,7 +43,7 @@ sub complete_dist {
     my %args = @_;
 
     my $word = $args{word} // '';
-    my $ci = $args{ci} // $Complete::OPT_CI;
+    my $ci = $args{ci} // $Complete::Setting::OPT_CI;
 
     $word =~ s!(::|-|/|\.)!-!g;
     Complete::Util::complete_array_elem(
@@ -68,7 +68,7 @@ Complete::Dist - Complete from list of installed Perl distributions
 
 =head1 VERSION
 
-This document describes version 0.04 of Complete::Dist (from Perl distribution Complete-Dist), released on 2015-09-03.
+This document describes version 0.05 of Complete::Dist (from Perl distribution Complete-Dist), released on 2015-09-09.
 
 =head1 SYNOPSIS
 
